FlutterAppInstallerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterAppInstallerPlatform
Implementers

Constructors

FlutterAppInstallerPlatform()
Constructs a FlutterAppInstallerPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasShellRootPermission → Future<bool>
no setter
isDeviceRooted → Future<bool>
no setter
isSystemApplication → Future<bool>
no setter
platformVersion → Future<String?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionCode → Future<int?>
no setter
versionName → Future<String?>
no setter

Methods

installApk({required String filePath, bool silently = false}) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterAppInstallerPlatform
The default instance of FlutterAppInstallerPlatform to use.
getter/setter pair